ImageNet-PI is a relabelled version of the standard ILSVRC2012 ImageNet
dataset in which the labels are provided by a collection of 16 deep neural
networks with different architectures pre-trained on the standard
ILSVRC2012. Specifically, the pre-trained models are downloaded from
tf.keras.applications.

In addition to the new labels, ImageNet-PI also provides meta-data about the
annotation process in the form of confidences of the models on their labels
and additional information about each model.

For more information see: [ImageNet-PI](https://github.com/google-research-datasets/imagenet_pi)